@@ -280,6 +280,7 @@ def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_s
 
     def func_batch_re(iterablei):
         if respective_kwargs:
+
             return [func(*i, **kw) for *i, kw in list(iterablei)]
         else:
             return [func(*i) for i in list(iterablei)]
@@ -288,25 +289,31 @@ def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_s
         return [func(i) for i in list(iterablei)]
 
     iterable = list(iterable)
-
-    if mode == "m":
-        # no tq
-
-        pool = multiprocessing.Pool(processes=n_jobs)
-        if tq:
-            rett = [result for result in tqdm(pool.imap(func=func, iterable=iterable, chunksize=batch_size),
-                                              total=len(iterable))]
-            pool.close()
-        else:
-            rett = [result for result in pool.imap(func=func, iterable=iterable, chunksize=batch_size)]
-            pool.close()
-        return rett
-
     batch = len(iterable) // batch_size + 1
     iterables = np.array_split(iterable, batch)
 
     parallel = Parallel(n_jobs=n_jobs, batch_size=batch_size, **parallel_para_dict)
 
+    if mode == "m":
+        # no tq
+        global func_batch_nree
+
+        def func_batch_nree(iterablei):
+            return [func(i) for i in list(iterablei)]
+
+        pool = multiprocessing.Pool(processes=n_jobs)
+        if tq:
+            rett = [result for result in tqdm(pool.imap(func=func_batch_nree, iterable=iterables),
+                                              total=len(iterables))]
+            pool.close()
+        else:
+            rett = [result for result in pool.imap(func=func_batch_nree, iterable=iterables)]
+            pool.close()
+        ret = []
+        [ret.extend(i) for i in rett]
+        del func_batch_nree
+        return ret
+
     if respective:
         func_batch = delayed(func_batch_re)
     else:
@@ -633,6 +640,23 @@ def get_name_without_suffix(module_name):
     return module_name
 
 
+def cmd_sys(d,cmd):
+    """run linux cmd"""
+    old = os.getcwd()
+    os.chdir(d)
+    os.system(cmd)
+    os.chdir(old)
+
+
+def cmd_popen(d,cmd):
+    """run linux cmd and return result."""
+    old = os.getcwd()
+    os.chdir(d)
+    res = os.popen(cmd).readlines()
+    os.chdir(old)
+    return res
+
+
 tt = TTClass()
 
 if __name__ == "__main__":
